import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';
import 'package:ocg_payment/src/metadata/colors.dart';
import 'package:ocg_payment/src/metadata/form_style.dart';
import 'package:ocg_payment/src/metadata/meta_text.dart';
import 'package:ocg_payment/src/widgets/primary_button.dart';
import 'package:ocg_payment/src/widgets/text_field.dart';

class BankAddScreen extends StatefulWidget {
  BankAddScreen({Key key}) : super(key: key);

  @override
  _BankAddScreenState createState() => _BankAddScreenState();
}

class _BankAddScreenState extends State<BankAddScreen> {
  PaymentBank _bank;
  final GlobalKey<FormState> _formKey = GlobalKey<FormState>();

  @override
  void initState() {
    super.initState();
    _bank = PaymentBank.named();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: false,
        title: Text(
          "Add Bank Account",
          style: TextStyle(
              color: MetaColors.primary,
              fontSize: 18,
              fontWeight: FontWeight.w500),
        ),
        elevation: 0,
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Expanded(
              child: SingleChildScrollView(
                child: Form(
                  key: _formKey,
                  child: Column(
                    children: [
                      TextFieldLabelWidget(
                        labelText: MetaText.accountNumber,
                        textInputType: TextInputType.number,
                        labelStyle: FormStyle.addBankAccountLabelStyle,
                        focusedBorder: FormStyle.addBankFocusedBorder,
                        enabledBorder: FormStyle.addBankEnabledBorder,
                        onChanged: (val) {
                          _bank = _bank.copyWith(account: val);
                        },
                        validator: (val) => InputHelper.isBlank(val)
                            ? "Please enter account number"
                            : null,
                      ),
                      TextFieldLabelWidget(
                        labelText: MetaText.ifsc,
                        textInputType: TextInputType.text,
                        labelStyle: FormStyle.addBankAccountLabelStyle,
                        focusedBorder: FormStyle.addBankFocusedBorder,
                        enabledBorder: FormStyle.addBankEnabledBorder,
                        onChanged: (val) {
                          _bank = _bank.copyWith(ifsc: val);
                        },
                        validator: (val) => InputHelper.isBlank(val)
                            ? "Please enter " + MetaText.ifsc
                            : null,
                      ),
                      TextFieldLabelWidget(
                        labelText: MetaText.bankName,
                        textInputType: TextInputType.text,
                        labelStyle: FormStyle.addBankAccountLabelStyle,
                        focusedBorder: FormStyle.addBankFocusedBorder,
                        enabledBorder: FormStyle.addBankEnabledBorder,
                        onChanged: (val) {
                          _bank = _bank.copyWith(name: val);
                        },
                        validator: (val) => InputHelper.isBlank(val)
                            ? "Please enter " + MetaText.bankName
                            : null,
                      ),
                    ],
                  ),
                ),
              ),
            ),
            PrimaryButton(
              label: MetaText.verifyNow,
              onPressed: () {
                if (_formKey.currentState.validate()) {
                  Navigator.of(context).pop(_bank);
                }
              },
            )
          ],
        ),
      ),
    );
  }
}
