import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';
import 'package:ocg_payment/src/metadata/colors.dart';
import 'package:ocg_payment/src/metadata/form_style.dart';
import 'package:ocg_payment/src/metadata/meta_text.dart';
import 'package:ocg_payment/src/widgets/primary_button.dart';
import 'package:ocg_payment/src/widgets/text_field.dart';

class CardAddScreen extends StatefulWidget {
  CardAddScreen({Key key}) : super(key: key);

  @override
  _CardAddScreenState createState() => _CardAddScreenState();
}

class _CardAddScreenState extends State<CardAddScreen> {
  PaymentCard _card;
  final GlobalKey<FormState> _formKey = GlobalKey<FormState>();
  TextEditingController _controller;

  @override
  void initState() {
    super.initState();
    _card = PaymentCard.named();
    _controller = TextEditingController();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: false,
        title: Text(
          "Add Card",
          style: TextStyle(
              color: MetaColors.primary,
              fontSize: 18,
              fontWeight: FontWeight.w500),
        ),
        elevation: 0,
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Expanded(
              child: SingleChildScrollView(
                child: Form(
                  key: _formKey,
                  child: Column(
                    children: [
                      TextFieldLabelWidget(
                        labelText: "Card No",
                        textInputType: TextInputType.number,
                        labelStyle: FormStyle.addBankAccountLabelStyle,
                        focusedBorder: FormStyle.addBankFocusedBorder,
                        enabledBorder: FormStyle.addBankEnabledBorder,
                        onChanged: (val) {
                          _card = _card.copyWith(cardNo: val);
                        },
                        maxLength: 16,
                        validator: (val) => InputHelper.isBlank(val)
                            ? "Please enter card number"
                            : val.length != 16
                                ? "Please enter valid number"
                                : null,
                      ),
                      TextFieldLabelWidget(
                        labelText: "CVV",
                        textInputType: TextInputType.number,
                        labelStyle: FormStyle.addBankAccountLabelStyle,
                        focusedBorder: FormStyle.addBankFocusedBorder,
                        enabledBorder: FormStyle.addBankEnabledBorder,
                        maxLength: 3,
                        onChanged: (val) {
                          _card = _card.copyWith(cvv: val);
                        },
                        validator: (val) => InputHelper.isBlank(val)
                            ? "Please enter " + "cvv"
                            : null,
                      ),
                      TextFieldLabelWidget(
                        labelText: "Date of expiry",
                        textInputType: TextInputType.text,
                        labelStyle: FormStyle.addBankAccountLabelStyle,
                        focusedBorder: FormStyle.addBankFocusedBorder,
                        enabledBorder: FormStyle.addBankEnabledBorder,
                        onTap: () async {
                          var date = await showDatePicker(
                              context: context,
                              initialDate: DateTime.now(),
                              firstDate: DateTime(DateTime.now().year - 1),
                              lastDate: DateTime(DateTime.now().year + 1));
                          if (date != null) {
                            _card = _card.copyWith(expiryDate: date);
                            _controller.text = DateHelper.beautifyDate(
                                _card.expiryDate,
                                relative: false);
                          }
                        },
                        readOnly: true,
                        controller: _controller,
                        validator: (val) => InputHelper.isBlank(val)
                            ? "Please enter " + "expiry date"
                            : null,
                      ),
                    ],
                  ),
                ),
              ),
            ),
            PrimaryButton(
              label: MetaText.verifyNow,
              onPressed: () {
                if (_formKey.currentState.validate()) {
                  Navigator.of(context).pop(_card.copyWith(
                      logo:
                          "https://logos-world.net/wp-content/uploads/2020/04/Visa-Logo.png"));
                }
              },
            )
          ],
        ),
      ),
    );
  }
}
