import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';

class WalletAddScreen extends StatefulWidget {
  const WalletAddScreen({
    Key key,
  }) : super(key: key);
  @override
  _WalletAddScreenState createState() => _WalletAddScreenState();
}

class _WalletAddScreenState extends State<WalletAddScreen> {
  final GlobalKey<FormState> formKey = GlobalKey<FormState>();
  TextEditingController editingController;
  int money;

  @override
  void initState() {
    super.initState();
    editingController = TextEditingController();
    BlocProvider.of<PaymentBalanceBloc>(context)
        .add(PaymentBalanceCheckEvent());
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        elevation: 0,
        backgroundColor: Colors.transparent,
      ),
      body: BlocBuilder<PaymentBalanceBloc, PaymentBalanceState>(
          builder: (context, state) {
        if (state is PaymentBalanceLoadingState) {
          return Center(
            child: AppProgressIndicator(),
          );
        }
        if (state is PaymentBalanceSuccessState) {
          var balance = state.balance;
          Amount amount = balance.amount;
          return Scaffold(
            body: Padding(
              padding: const EdgeInsets.all(16.0),
              child: BlocBuilder<PaymentBalanceBloc, PaymentBalanceState>(
                  builder: (context, state) {
                return SingleChildScrollView(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisSize: MainAxisSize.min,
                    children: <Widget>[
                      SizedBox(
                        height: 32,
                      ),
                      Text(
                        "Add Money to Wallet",
                        style: TextStyle(
                          fontSize: 25,
                          fontWeight: FontWeight.bold,
                        ),
                      ),
                      SizedBox(
                        height: 8,
                      ),
                      Text(
                        "Available Balance ${amount?.amount} ${amount?.currency}",
                        style: TextStyle(
                          fontSize: 14,
                        ),
                      ),
                      SizedBox(
                        height: 42,
                      ),
                      Form(
                          key: formKey,
                          child: TextFormField(
                            controller: editingController,
                            onChanged: (val) {
                              money = int.tryParse(val);
                            },
                            validator: (val) {
                              return val.isEmpty
                                  ? "Please enter valid amount"
                                  : null;
                            },
                            autofocus: true,
                            inputFormatters: [
                              FilteringTextInputFormatter.digitsOnly
                            ],
                            keyboardType: TextInputType.number,
                            decoration: InputDecoration(
                                hintStyle: TextStyle(color: Colors.black45),
                                hintText: "Amount",
                                suffixText: "${amount?.currency}"),
                            style: TextStyle(
                                fontSize: 32, fontWeight: FontWeight.w800),
                          )),
                      SizedBox(
                        height: 24,
                      ),
                      Wrap(
                        children: [500, 1000, 1500]
                            .map((val) => Padding(
                                  padding: const EdgeInsets.only(right: 18),
                                  child: OutlineButton(
                                    onPressed: () {
                                      editingController.text = "$val";
                                      money = val;
                                    },
                                    borderSide: BorderSide(
                                        color: Colors.black.withOpacity(0.2)),
                                    shape: RoundedRectangleBorder(
                                        borderRadius:
                                            BorderRadius.circular(32)),
                                    child: Padding(
                                      padding: const EdgeInsets.symmetric(
                                          horizontal: 12, vertical: 10),
                                      child: Text("$val"),
                                    ),
                                  ),
                                ))
                            .toList(),
                      )
                    ],
                  ),
                );
              }),
            ),
            floatingActionButton: Padding(
              padding: const EdgeInsets.symmetric(vertical: 16, horizontal: 12),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: <Widget>[
                  SizedBox(
                    width: MediaQuery.of(context).size.width * 0.86,
                    child: RoundedButton(
                      "Continue",
                      color: Theme.of(context).primaryColor,
                      onTap: () async {
                        if (formKey.currentState.validate()) {
                          var newAmount = Amount.named(
                              amount: int.parse(editingController.text),
                              currency: amount.currency);
                          var response = await PaymentHandler.of(context)
                              .addMoney(newAmount);
                          if (response.isSuccess) {
                            Navigator.of(context).pop(response);
                          } else {
                            AppUIHelper.of(context)
                                .showToast(text: "${response.error}");
                          }
                        }
                      },
                    ),
                  ),
                  CupertinoButton(child: Text("Need Help?"), onPressed: () {})
                ],
              ),
            ),
            floatingActionButtonLocation:
                FloatingActionButtonLocation.centerFloat,
          );
        }
        if (state is PaymentBalanceErrorState) {
          return Center(
            child: AppErrorWidget(error: state.error),
          );
        }
        return Container();
      }),
    );
  }
}
